@@ -654,18 +654,19 @@ def bindResource(apiInstance,resourceInstance):
 @Function
 def validateArgs(args, requestClass, resourceInstanceMethod):
     if ObjectHelper.isNotNone(requestClass):
-        if Serializer.isSerializerList(requestClass) and  0 < len(requestClass):
-            resourceInstance = args[0]
-            for index in range(len(requestClass)):
-                objectRequest = args[index + 1]
-                expecteObjectClass = requestClass[index]
-                ExceptionHandler.validateArgs(resourceInstance, resourceInstanceMethod, objectRequest, expecteObjectClass)
-                if Serializer.isSerializerList(args[index + 1]) and len(args[index + 1]) > 0:
-                    expecteObjectClass = requestClass[index][0]
-                    for objectRequest in args[index + 1]:
-                        ExceptionHandler.validateArgs(resourceInstance, resourceInstanceMethod, objectRequest, expecteObjectClass)
+        if Serializer.isSerializerList(requestClass):
+            if 0 < len(requestClass):
+                resourceInstance = args[0]
+                for index in range(len(requestClass)):
+                    objectRequest = args[index + 1]
+                    expecteObjectClass = requestClass[index]
+                    ExceptionHandler.validateArgs(resourceInstance, resourceInstanceMethod, objectRequest, expecteObjectClass)
+                    if Serializer.isSerializerList(args[index + 1]) and len(args[index + 1]) > 0:
+                        expecteObjectClass = requestClass[index][0]
+                        for objectRequest in args[index + 1]:
+                            ExceptionHandler.validateArgs(resourceInstance, resourceInstanceMethod, objectRequest, expecteObjectClass)
         else:
-            validateArgs(args, requestClass, resourceInstanceMethod)
+            validateArgs(args, [requestClass], resourceInstanceMethod)
 
 def validateKwargs(kwargs, resourceInstance, resourceInstanceMethod, requestHeaderClass, requestParamClass):
     classListToValidate = []
